Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: src/crankshaft/mips64/lithium-codegen-mips64.cc

Issue 1409123003: [runtime] Avoid @@isConcatSpreadable lookup for fast path Array.prototype.concat (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: simplifications Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/crankshaft/mips64/lithium-codegen-mips64.cc
diff --git a/src/crankshaft/mips64/lithium-codegen-mips64.cc b/src/crankshaft/mips64/lithium-codegen-mips64.cc
index f0ead54a962725e615c08e3dfc622b41b6041054..9bdb7bf39434e51d8d704b473e03f051c734a62d 100644
--- a/src/crankshaft/mips64/lithium-codegen-mips64.cc
+++ b/src/crankshaft/mips64/lithium-codegen-mips64.cc
@@ -3253,13 +3253,15 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
__ Branch(&done, ne, result, Operand(scratch));
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
// it needs to bail out.
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex);
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex);
// The comparison only needs LS bits of value, which is a smi.
__ ld(result, FieldMemOperand(result, Cell::kValueOffset));
- DeoptimizeIf(ne, instr, Deoptimizer::kHole, result,
- Operand(Smi::FromInt(Isolate::kArrayProtectorValid)));
+ DeoptimizeIf(
+ ne, instr, Deoptimizer::kHole, result,
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid)));
}
__ LoadRoot(result, Heap::kUndefinedValueRootIndex);
__ bind(&done);
@@ -3253,13 +3253,15 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid.
+ // Otherwise
// it needs to bail out.

Powered by Google App Engine
This is Rietveld 408576698